==> peperit_2.0_estable.zip: themes/peperit/html_files/componentes/plantilla/cabeceras/cabeceraDos.php <==
<?php

/* 
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 * PLANTILLA  Grima
 */
//Opciones para personalizar la plantilla
$tieneBlog = Theme::getConfigParam('hasBlog', false);
$cestaDesplegable = Theme::getConfigParam('cestaDesplegable', 'cestaDesplegable.php');
?>
<header>
    <div class="busquedaCesta">
        <div class="<?=Theme::getConfigParam('container_style', 'container');?>">
            <div class="row">
                <div id="header_logo" class="col-xs-6  col-md-3"> 
                    <a href="<?= Shop::$configuracion->url ?>" title="<?= Shop::$empresa->nombre; ?> Home"> 
                        <img class="logo img-responsive" src="<?= Shop::$configuracion->url; ?><?= _WS_THEME_RESOURCE_DIR_; ?>images/logo.png" alt="bookshop_home3" > 
                    </a>
                </div>
                <div id="sticky_top" class="col-xs-12  col-md-9">
                    <nav class="nav col-xs-6 col-md-12 col-lg-12">
                        <div class="nav_info col-xs-6 col-sm-6 col-lg-4 col-lg-offset-2">
                            <a href="tel:+34<?= Shop::$empresa->telefono_empresa ?>" class="telefono" title="El telefono de empresa es <?= Shop::$empresa->telefono_empresa ?>">
                                <i class="mdi mdi-phone"> </i><?= Shop::$empresa->telefono_empresa ?>
                            </a>
                            <a href="mailto:<?= Shop::$empresa->email_empresa; ?>" class="email  hidden-xs" title="El email de empresa es <?= Shop::$empresa->email_empresa; ?>">
                                <i class="mdi mdi-email"> </i><?= Shop::$empresa->nombre ?>
                            </a>
                            <div class="nav_redes_sociales">
                                <?php
                                new Widget($_WH->GW("redes_sociales", "redes_sociales"), new OpcionesWidget(array("ficheroRedSocial" => "itemSocialMediaCabecera")));
                                ?>
                            </div>
                        </div>
                        <div class="header_links col-xs-6 col-sm-6 col-lg-6">
                            <?php
                            //Creamos la zona de usuario
                            $opciones = new OpcionesWidget(array('fichero_sin_login' => 'menu_usuario_sin_login', 'fichero_con_login' => 'menu_usuario_con_login'));
                            $widget_menu_usuario = new Widget($_WH->GW('usuario', 'menu_usuario_completo'), $opciones);
                            ?>
                        </div>
                    </nav>
                    <div id="search_block_top" class=" col-xs-8 col-lg-6 col-lg-offset-1">
                        <button type="button" class="boton" data-toggle="collapse" data-target="#search_block_top_collapse"><i class="mdi mdi-magnify"></i></button>
                        <div id="search_block_top_collapse" class="collapse">
                            <div class="field-search">
                                <?php
                                $opcionesBuscador = new OpcionesWidget(array('idFormularioBusqueda' => 'searchbox'));
                                $widget_buscador_simple = new Widget($_WH->GW("buscador", "buscador_simpleV2"), $opcionesBuscador);
                                ?>
                            </div>
                        </div>
                    </div>
                   <?php
					Theme::include_file($cestaDesplegable);
					?>
                </div>
            </div>
        </div>
    </div>
    <div id="contenedorNav">
        <nav class="main-navigation">
            <div class="<?=Theme::getConfigParam('container_style', 'container');?>">
                <div class="row">
					<?php
					$ficheroMenu = Theme::getConfigParam('menuSuperior', 'menuCategoriasVmenuHsticky.php');
					Theme::include_file($ficheroMenu);
					?>
                </div>
            </div>
        </nav>
    </div>
</header>

==> peperit_2.1_estable.zip: themes/peperit/html_files/componentes/plantilla/cabeceras/cabeceraDos.php <==
<?php

/* 
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 * PLANTILLA  Grima
 */
//Opciones para personalizar la plantilla
$tieneBlog = Theme::getConfigParam('hasBlog', false);
$cestaDesplegable = Theme::getConfigParam('cestaDesplegable', 'cestaDesplegable.php');
?>
<header>
    <div class="busquedaCesta">
        <div class="<?=Theme::getConfigParam('container_style', 'container');?>">
            <div class="row">
                <div id="header_logo" class="col-xs-6  col-md-3"> 
                    <a href="<?= Shop::$configuracion->url ?>" title="<?= Shop::$empresa->nombre; ?> Home"> 
                        <img class="logo img-responsive" src="<?= Shop::$configuracion->url; ?><?= _WS_THEME_RESOURCE_DIR_; ?>images/logo.png" alt="bookshop_home3" > 
                    </a>
                </div>
                <div id="sticky_top" class="col-xs-12  col-md-9">
                    <nav class="nav col-xs-6 col-md-12 col-lg-12">
                        <div class="nav_info col-xs-6 col-sm-6 col-lg-4 col-lg-offset-2">
                            <a href="tel:+34<?= Shop::$empresa->telefono_empresa ?>" class="telefono" title="El telefono de empresa es <?= Shop::$empresa->telefono_empresa ?>">
                                <i class="mdi mdi-phone"> </i><?= Shop::$empresa->telefono_empresa ?>
                            </a>
                            <a href="mailto:<?= Shop::$empresa->email_empresa; ?>" class="email  hidden-xs" title="El email de empresa es <?= Shop::$empresa->email_empresa; ?>">
                                <i class="mdi mdi-email"> </i><?= Shop::$empresa->nombre ?>
                            </a>
                            <div class="nav_redes_sociales">
                                <?php
                                new Widget($_WH->GW("redes_sociales", "redes_sociales"), new OpcionesWidget(array("ficheroRedSocial" => "itemSocialMediaCabecera")));
                                ?>
                            </div>
                        </div>
                        <div class="header_links col-xs-6 col-sm-6 col-lg-6">
                            <?php
                            //Creamos la zona de usuario
                            $opciones = new OpcionesWidget(array('fichero_sin_login' => 'menu_usuario_sin_login', 'fichero_con_login' => 'menu_usuario_con_login'));
                            $widget_menu_usuario = new Widget($_WH->GW('usuario', 'menu_usuario_completo'), $opciones);
                            ?>
                        </div>
                    </nav>
                    <div id="search_block_top" class=" col-xs-8 col-lg-6 col-lg-offset-1">
                        <button type="button" class="boton" data-toggle="collapse" data-target="#search_block_top_collapse" onclick="setTimeout(function() { $('.buscador_simpleV2 input.search_query').focus(); }, 500);"><i class="mdi mdi-magnify"></i></button>
                        <div id="search_block_top_collapse" class="collapse">
                            <div class="field-search">
                                <?php
                                $opcionesBuscador = new OpcionesWidget(array('idFormularioBusqueda' => 'searchbox'));
                                $widget_buscador_simple = new Widget($_WH->GW("buscador", "buscador_simpleV2"), $opcionesBuscador);
                                ?>
                            </div>
                        </div>
                    </div>
                   <?php
					Theme::include_file($cestaDesplegable);
					?>
                </div>
            </div>
        </div>
    </div>
    <div id="contenedorNav">
        <nav class="main-navigation">
            <div class="<?=Theme::getConfigParam('container_style', 'container');?>">
                <div class="row">
					<?php
					$ficheroMenu = Theme::getConfigParam('menuSuperior', 'menuCategoriasVmenuHsticky.php');
					Theme::include_file($ficheroMenu);
					?>
                </div>
            </div>
        </nav>
    </div>
</header>
